#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_BITWISE_NOTOR_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_BITWISE_NOTOR_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/simd/bitwise_notor.hpp>

#endif
